@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer2::Logger::LogReport;
 use vars '$VERSION';
-$VERSION = '1.11';
+$VERSION = '1.12';
 
 # ABSTRACT: Dancer2 logger engine for Log::Report
 
@@ -14,7 +14,7 @@ use warnings;
 use Moo;
 use Dancer2::Core::Types;
 use Scalar::Util qw/blessed/;
-use Log::Report  'log-report', syntax => 'REPORT', mode => 'DEBUG';
+use Log::Report  'log-report', syntax => 'REPORT';
 
 our $AUTHORITY = 'cpan:MARKOV';
 
